@@ -1,9 +1,9 @@
 package Perinci::Sub::To::CLIDocData;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-10'; # DATE
+our $DATE = '2021-07-11'; # DATE
 our $DIST = 'Perinci-Sub-To-CLIDocData'; # DIST
-our $VERSION = '0.297'; # VERSION
+our $VERSION = '0.298'; # VERSION
 
 use 5.010001;
 use strict;
@@ -435,7 +435,7 @@ sub gen_cli_doc_data_from_meta {
         require Getopt::Long::Util;
         my @plain_opts;
         my @pod_opts;
-        my %opt_locations; # key=argname
+        my %opt_locations; # key=$ARGNAME or "common:$SOMEKEY"
         for my $ospec (sort {
             ($ggls_res->[3]{'func.specmeta'}{$a}{is_neg} ? 1:0) <=> ($ggls_res->[3]{'func.specmeta'}{$b}{is_neg} ? 1:0) ||
             ($ggls_res->[3]{'func.specmeta'}{$a}{is_alias} ? 1:0) <=> ($ggls_res->[3]{'func.specmeta'}{$b}{is_alias} ? 1:0) ||
@@ -453,8 +453,6 @@ sub gen_cli_doc_data_from_meta {
 
             my $copt = defined $ospecmeta->{common_opt} ? $common_opts->{ $ospecmeta->{common_opt} } : undef;
 
-            #use DD; print "ospec: $ospec, ospecmeta: ", DD::dmp($ospecmeta), ", argprop: ", DD::dmp($argprop), ", copt: ", DD::dmp($copt), "\n";
-
             next if defined $ospecmeta->{common_opt} && $copt->{usage};
             my $caption_from_schema;
             if ($argprop && $argprop->{schema} &&
@@ -488,16 +486,23 @@ sub gen_cli_doc_data_from_meta {
             my $plain_opt = $hres->{plaintext};
             my $pod_opt   = $hres->{pod};
 
-            # put option from arg and its cmdline aliases or its json/yaml
-            # version and its negation version together as alternates
-            if ($ospecmeta->{is_alias} || $ospecmeta->{is_neg} || $ospecmeta->{is_json} || $ospecmeta->{is_yaml}) {
-                push @{ $plain_opts[ $opt_locations{$ospecmeta->{arg}} ] }, $plain_opt;
-                push @{ $pod_opts  [ $opt_locations{$ospecmeta->{arg}} ] }, $pod_opt;
+            my $key;
+            if ($copt && defined $copt->{key}) {
+                # group common options by key.
+                $key = "00common:" . $copt->{key};
+            } elsif ($ospecmeta->{is_alias} || $ospecmeta->{is_neg} || $ospecmeta->{is_json} || $ospecmeta->{is_yaml}) {
+                # put option from arg and its cmdline aliases or its json/yaml
+                # version and its negation version together as alternates.
+                $key = $ospecmeta->{arg};
             } else {
-                $opt_locations{$ospecmeta->{arg} // $ospec} //= scalar @plain_opts;
-                push @plain_opts, [$plain_opt];
-                push @pod_opts  , [$pod_opt  ];
+                $key = $ospec;
             }
+            $key =~ s/_/-/g;
+
+            $opt_locations{$key} //= scalar @plain_opts;
+            push @{ $plain_opts[ $opt_locations{$key} ] }, $plain_opt;
+            push @{ $pod_opts  [ $opt_locations{$key} ] }, $pod_opt;
+            #use Data::Dmp; print "key: $key, ospec: $ospec, ospecmeta: ", dmp($ospecmeta), ", argprop: ", dmp($argprop), ", copt: ", dmp($copt), "\n";
         }
 
         $clidocdata->{compact_usage_line} = "[[prog]]".
@@ -586,7 +591,7 @@ Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure
 
 =head1 VERSION
 
-This document describes version 0.297 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2021-07-10.
+This document describes version 0.298 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2021-07-11.
 
 =head1 SYNOPSIS
 
@@ -832,7 +837,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
